==> eiffelstudio-18.07.10.1981.tar: F_code/C18/xm868.c <==
/*
 * Code for class XM_XPATH_COLLECTION_FILE_SCHEME_RESOLVER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm868.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XPATH_COLLECTION_FILE_SCHEME_RESOLVER}.make */
void F1739_16699 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc1);
	RTLR(3,arg1);
	RTLR(4,tr2);
	RTLIU(5);
	
	RTGC;
	tr1 = RTMS_EX_H("file",4,1718185061);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	loc1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_4_);
	tr1 = RTOSCF(9587,F1198_9587,(Current));
	loc1 = F1457_12095(RTCW(loc1), tr1);
	tr1 = RTMS_EX_H("yes",3,7955827);
	tr2 = RTOSCF(15222,F1672_15222,(RTCW(arg1)));
	F1457_12114(RTCW(loc1), tr1, tr2);
	RTLE;
}

/* {XM_XPATH_COLLECTION_FILE_SCHEME_RESOLVER}.last_error */
EIF_REFERENCE F1739_16700 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {XM_XPATH_COLLECTION_FILE_SCHEME_RESOLVER}.resolve */
void F1739_16701 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(10);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLR(4,tr3);
	RTLR(5,tr4);
	RTLR(6,loc3);
	RTLR(7,loc1);
	RTLR(8,loc2);
	RTLR(9,arg2);
	RTLIU(10);
	
	RTGC;
	tb1 = F1630_14158(RTCW(arg1));
	if (tb1) {
		tr1 = RTLNSMART(eif_new_type(1631, 0).id);
		tr2 = RTMS_EX_H("Fragment identifiers are not allowed on file URIs for fn:collection()",69,1467271465);
		tr3 = RTOSCF(9585,F1198_9585,(Current));
		tr4 = RTMS_EX_H("FODC0004",8,2066165812);
		F1632_14218(RTCW(tr1), tr2, tr3, tr4, ((EIF_INTEGER_32) 3L));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	} else {
		tb1 = F1630_14157(RTCW(arg1));
		if (tb1) {
			tr1 = RTLNSMART(eif_new_type(1631, 0).id);
			tr2 = RTMS_EX_H("Parameters are not allowed on file URIs",39,833137523);
			tr3 = RTOSCF(9585,F1198_9585,(Current));
			tr4 = RTMS_EX_H("FODC0004",8,2066165812);
			F1632_14218(RTCW(tr1), tr2, tr3, tr4, ((EIF_INTEGER_32) 3L));
			RTAR(Current, tr1);
			*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
		} else {
			tb1 = F1630_14150(RTCW(arg1));
			if ((EIF_BOOLEAN) !tb1) {
				tr1 = RTLNSMART(eif_new_type(1631, 0).id);
				tr2 = RTMS_EX_H("File URI passed to fn:collection() must include a path",54,1233586536);
				tr3 = RTOSCF(9585,F1198_9585,(Current));
				tr4 = RTMS_EX_H("FODC0004",8,2066165812);
				F1632_14218(RTCW(tr1), tr2, tr3, tr4, ((EIF_INTEGER_32) 3L));
				RTAR(Current, tr1);
				*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
			} else {
				tb1 = F1630_14151(RTCW(arg1));
				if (tb1) {
					tr1 = RTLNSMART(eif_new_type(1631, 0).id);
					tr2 = RTMS_EX_H("File URIs for fn:collection() must end in a /",45,2070207279);
					tr3 = RTOSCF(9585,F1198_9585,(Current));
					tr4 = RTMS_EX_H("FODC0004",8,2066165812);
					F1632_14218(RTCW(tr1), tr2, tr3, tr4, ((EIF_INTEGER_32) 3L));
					RTAR(Current, tr1);
					*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
				} else {
					tr1 = RTOSCF(4306,F895_4306,(Current));
					loc3 = F1505_12564(RTCW(tr1), arg1);
					if ((EIF_BOOLEAN)(loc3 != NULL)) {
						tr1 = RTOSCF(12170,F1472_12170,(Current));
						loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R10056[Dtype(tr1)-1509])(RTCW(tr1), loc3);
					}
					tb1 = '\01';
					if (!(EIF_BOOLEAN)(loc1 == NULL)) {
						tr1 = RTOSCF(12170,F1472_12170,(Current));
						tb2 = F1509_12675(RTCW(tr1), loc1);
						tb1 = (EIF_BOOLEAN) !tb2;
					}
					if (tb1) {
						tr1 = RTLNSMART(eif_new_type(1631, 0).id);
						tr2 = RTMS_EX_H("Directory specified in file: argument to fn:collection() does not exist",71,735225716);
						tr3 = RTOSCF(9585,F1198_9585,(Current));
						tr4 = RTMS_EX_H("FODC0004",8,2066165812);
						F1632_14218(RTCW(tr1), tr2, tr3, tr4, ((EIF_INTEGER_32) 3L));
						RTAR(Current, tr1);
						*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
					} else {
						tr1 = RTLNS(eif_new_type(1473, 0x00).id, 1473, _OBJSIZ_6_2_0_1_0_2_0_0_);
						F1474_12208(RTCW(tr1), loc1);
						loc2 = (EIF_REFERENCE) tr1;
						F1737_16691(Current, arg1, arg1, arg2, loc2);
					}
				}
			}
		}
	}
	RTLE;
}

void EIF_Minit868 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C18/xm868.c <==
/*
 * Code for class XM_XPATH_COLLECTION_FILE_SCHEME_RESOLVER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm868.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XPATH_COLLECTION_FILE_SCHEME_RESOLVER}.make */
void F1745_16758 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc1);
	RTLR(3,arg1);
	RTLR(4,tr2);
	RTLIU(5);
	
	RTGC;
	tr1 = RTMS_EX_H("file",4,1718185061);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	loc1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_4_);
	tr1 = RTOSCF(9657,F1200_9657, (Current));
	loc1 = F1465_12169(RTCW(loc1), tr1);
	tr1 = RTMS_EX_H("yes",3,7955827);
	tr2 = RTOSCF(15309,F1681_15309, (RTCW(arg1)));
	F1465_12189(RTCW(loc1), tr1, tr2);
	RTLE;
}

/* {XM_XPATH_COLLECTION_FILE_SCHEME_RESOLVER}.last_error */
EIF_REFERENCE F1745_16759 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {XM_XPATH_COLLECTION_FILE_SCHEME_RESOLVER}.resolve */
void F1745_16760 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(10);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLR(4,tr3);
	RTLR(5,tr4);
	RTLR(6,loc3);
	RTLR(7,loc1);
	RTLR(8,loc2);
	RTLR(9,arg2);
	RTLIU(10);
	
	RTGC;
	tb1 = F1639_14240(RTCW(arg1));
	if (tb1) {
		tr1 = RTLNSMART(eif_new_type(1640, 0).id);
		tr2 = RTMS_EX_H("Fragment identifiers are not allowed on file URIs for fn:collection()",69,1467271465);
		tr3 = RTOSCF(9655,F1200_9655, (Current));
		tr4 = RTMS_EX_H("FODC0004",8,2066165812);
		F1641_14305(RTCW(tr1), tr2, tr3, tr4, ((EIF_INTEGER_32) 3L));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	} else {
		tb1 = F1639_14239(RTCW(arg1));
		if (tb1) {
			tr1 = RTLNSMART(eif_new_type(1640, 0).id);
			tr2 = RTMS_EX_H("Parameters are not allowed on file URIs",39,833137523);
			tr3 = RTOSCF(9655,F1200_9655, (Current));
			tr4 = RTMS_EX_H("FODC0004",8,2066165812);
			F1641_14305(RTCW(tr1), tr2, tr3, tr4, ((EIF_INTEGER_32) 3L));
			RTAR(Current, tr1);
			*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
		} else {
			tb1 = F1639_14232(RTCW(arg1));
			if ((EIF_BOOLEAN) !tb1) {
				tr1 = RTLNSMART(eif_new_type(1640, 0).id);
				tr2 = RTMS_EX_H("File URI passed to fn:collection() must include a path",54,1233586536);
				tr3 = RTOSCF(9655,F1200_9655, (Current));
				tr4 = RTMS_EX_H("FODC0004",8,2066165812);
				F1641_14305(RTCW(tr1), tr2, tr3, tr4, ((EIF_INTEGER_32) 3L));
				RTAR(Current, tr1);
				*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
			} else {
				tb1 = F1639_14233(RTCW(arg1));
				if (tb1) {
					tr1 = RTLNSMART(eif_new_type(1640, 0).id);
					tr2 = RTMS_EX_H("File URIs for fn:collection() must end in a /",45,2070207279);
					tr3 = RTOSCF(9655,F1200_9655, (Current));
					tr4 = RTMS_EX_H("FODC0004",8,2066165812);
					F1641_14305(RTCW(tr1), tr2, tr3, tr4, ((EIF_INTEGER_32) 3L));
					RTAR(Current, tr1);
					*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
				} else {
					tr1 = RTOSCF(3484,F458_3484, (Current));
					loc3 = F1513_12645(RTCW(tr1), arg1);
					if ((EIF_BOOLEAN)(loc3 != NULL)) {
						tr1 = RTOSCF(12245,F1480_12245, (Current));
						loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R10112[Dtype(RTCW(tr1))-1517])(tr1, loc3);
					}
					tb1 = '\01';
					if (!(EIF_BOOLEAN)(loc1 == NULL)) {
						tr1 = RTOSCF(12245,F1480_12245, (Current));
						tb2 = F1517_12756(RTCW(tr1), loc1);
						tb1 = (EIF_BOOLEAN) !tb2;
					}
					if (tb1) {
						tr1 = RTLNSMART(eif_new_type(1640, 0).id);
						tr2 = RTMS_EX_H("Directory specified in file: argument to fn:collection() does not exist",71,735225716);
						tr3 = RTOSCF(9655,F1200_9655, (Current));
						tr4 = RTMS_EX_H("FODC0004",8,2066165812);
						F1641_14305(RTCW(tr1), tr2, tr3, tr4, ((EIF_INTEGER_32) 3L));
						RTAR(Current, tr1);
						*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
					} else {
						loc2 = RTLNS(eif_new_type(1481, 0x01).id, 1481, _OBJSIZ_6_2_0_1_0_2_0_0_);
						F1482_12283(RTCW(loc2), loc1);
						F1743_16750(Current, arg1, arg1, arg2, loc2);
					}
				}
			}
		}
	}
	RTLE;
}

void EIF_Minit868 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
